Module davclient
corroded_
dav_
cli
0.6.0
Module davclient
Module Items
Structs
Enums
In crate corroded_
dav_
cli
corroded_dav_cli
Module
davclient
Structs

Client
Ext
A WebDAV client, based on rustydav, but exposing an interface with results better abstracted from raw http reponses.
Enums

DavCtrl
Error